from setuptools import setup

setup(name='distributions_jcp',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_jcp'],
      author = 'dan',
      author_email = 'dan@email.com',
      zip_safe=False)
